@@ -25,7 +25,7 @@ try:
 
     elif sys.platform == 'linux':
         lib_agora_rtc_path = os.path.join(lib_dir, 'libagora_rtc_sdk.so')
-        #ctypes.CDLL(os.path.join(lib_dir, 'libagora-fdkaac.so'))
+        ctypes.CDLL(os.path.join(lib_dir, 'libagora-fdkaac.so'))
         agora_lib = ctypes.CDLL(lib_agora_rtc_path)
 except OSError as e:
     logger.error(f"Error loading the library: {e}")
